==> icepdf-core-5.0.2-sources.jar: org/icepdf/core/pobjects/graphics/commands/DrawDrawCmd.java <==
/*
 * Copyright 2006-2013 ICEsoft Technologies Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS
 * IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.icepdf.core.pobjects.graphics.commands;

import org.icepdf.core.pobjects.Page;
import org.icepdf.core.pobjects.graphics.OptionalContentState;
import org.icepdf.core.pobjects.graphics.PaintTimer;

import java.awt.*;
import java.awt.geom.AffineTransform;

/**
 * The DrawDrawCmd (no didn't stutter) will call draw and the Graphics2D context
 * for the currentShape.  The execute method will not draw the currentShape
 * if the shape does not interest the current graphics clip.
 *
 * @since 5.0
 */
public class DrawDrawCmd extends AbstractDrawCmd {

    @Override
    public Shape paintOperand(Graphics2D g, Page parentPage, Shape currentShape,
                              Shape clip, AffineTransform base,
                              OptionalContentState optionalContentState,
                              boolean paintAlpha, PaintTimer paintTimer) {
        if (optionalContentState.isVisible() &&
                currentShape.intersects(g.getClip().getBounds2D()) ||
                (currentShape.getBounds2D().getWidth() < 1.0 ||
                        currentShape.getBounds2D().getHeight() < 1.0)) {
            g.draw(currentShape);
            // Send a PaintPage Event to listeners
            if (parentPage != null && paintTimer.shouldTriggerRepaint()) {
                parentPage.notifyPaintPageListeners();
            }
        }
        return currentShape;
    }
}

==> icepdf-core-5.0.7-sources.jar: org/icepdf/core/pobjects/graphics/commands/DrawDrawCmd.java <==
/*
 * Copyright 2006-2014 ICEsoft Technologies Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS
 * IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.icepdf.core.pobjects.graphics.commands;

import org.icepdf.core.pobjects.Page;
import org.icepdf.core.pobjects.graphics.OptionalContentState;
import org.icepdf.core.pobjects.graphics.PaintTimer;

import java.awt.*;
import java.awt.geom.AffineTransform;

/**
 * The DrawDrawCmd (no didn't stutter) will call draw and the Graphics2D context
 * for the currentShape.  The execute method will not draw the currentShape
 * if the shape does not interest the current graphics clip.
 *
 * @since 5.0
 */
public class DrawDrawCmd extends AbstractDrawCmd {

    @Override
    public Shape paintOperand(Graphics2D g, Page parentPage, Shape currentShape,
                              Shape clip, AffineTransform base,
                              OptionalContentState optionalContentState,
                              boolean paintAlpha, PaintTimer paintTimer) {
        if (g.getClip() != null && optionalContentState.isVisible() &&
                currentShape.intersects(g.getClip().getBounds2D()) ||
                (currentShape.getBounds2D().getWidth() < 1.0 ||
                        currentShape.getBounds2D().getHeight() < 1.0)) {
            g.draw(currentShape);
            // Send a PaintPage Event to listeners
            if (parentPage != null && paintTimer.shouldTriggerRepaint()) {
                parentPage.notifyPaintPageListeners();
            }
        }
        // coupld corner cases where we want to paint the shape when we don't have a clip.
        else if (g.getClip() == null) {
            g.draw(currentShape);
            // Send a PaintPage Event to listeners
            if (parentPage != null && paintTimer.shouldTriggerRepaint()) {
                parentPage.notifyPaintPageListeners();
            }
        }
        return currentShape;
    }
}
